package cn.fw.hestia.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author : kurisu
 * @className : SendStateEnum
 * @description : 发送状态
 * @date: 2020-08-11 17:37
 */
public enum SendStateEnum implements IEnum<Integer> {
    /**
     * 等待回调
     */
    OK(1, "发送成功"),
    /**
     * 完成回调
     */
    FAIL(2, "发送失败"),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    SendStateEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static SendStateEnum ofValue(final Integer value) {
        for (final SendStateEnum stateEnum : SendStateEnum.values()) {
            if (stateEnum.value.equals(value)) {
                return stateEnum;
            }
        }
        return null;
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final SendStateEnum stateEnum : SendStateEnum.values()) {
            if (stateEnum.value.equals(value)) {
                return stateEnum.getName();
            }
        }
        return "";
    }
}
